#ifndef NT2_INCLUDE_FUNCTIONS_ISSCALAR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISSCALAR_HPP_INCLUDED

#include <nt2/predicates/include/functions/isscalar.hpp>

#endif
